@@ -947,17 +947,21 @@ int edge_contains_coplanar_point(const GEOGRAPHIC_EDGE *e, const GEOGRAPHIC_POIN
 */
 double sphere_distance(const GEOGRAPHIC_POINT *s, const GEOGRAPHIC_POINT *e)
 {
-	double d_lon = e->lon - s->lon;
-	double cos_d_lon = cos(d_lon);
-	double cos_lat_e = cos(e->lat);
-	double sin_lat_e = sin(e->lat);
-	double cos_lat_s = cos(s->lat);
-	double sin_lat_s = sin(s->lat);
+	double d_lon, cos_d_lon, cos_lat_e, sin_lat_e, cos_lat_s, sin_lat_s;
+	double a1, a2, a, b;
 
-	double a1 = POW2(cos_lat_e * sin(d_lon));
-	double a2 = POW2(cos_lat_s * sin_lat_e - sin_lat_s * cos_lat_e * cos_d_lon);
-	double a = sqrt(a1 + a2);
-	double b = sin_lat_s * sin_lat_e + cos_lat_s * cos_lat_e * cos_d_lon;
+	if (FP_EQUALS(s->lat, e->lat) && FP_EQUALS(s->lon, e->lon)) return 0.0;
+	d_lon = e->lon - s->lon;
+	cos_d_lon = cos(d_lon);
+	cos_lat_e = cos(e->lat);
+	sin_lat_e = sin(e->lat);
+	cos_lat_s = cos(s->lat);
+	sin_lat_s = sin(s->lat);
+
+	a1 = POW2(cos_lat_e * sin(d_lon));
+	a2 = POW2(cos_lat_s * sin_lat_e - sin_lat_s * cos_lat_e * cos_d_lon);
+	a = sqrt(a1 + a2);
+	b = sin_lat_s * sin_lat_e + cos_lat_s * cos_lat_e * cos_d_lon;
 	return atan2(a, b);
 }
 
@@ -1913,7 +1917,7 @@ static double ptarray_distance_spheroid(const POINTARRAY *pa1, const POINTARRAY
 				nearest2 = g2;
 			}
 			/* We've gotten closer than the tolerance... */
-			if ( d < tolerance )
+			if ( d <= tolerance )
 			{
 				/* Working on a sphere? The answer is correct, return */
 				if ( use_sphere )
@@ -1921,7 +1925,7 @@ static double ptarray_distance_spheroid(const POINTARRAY *pa1, const POINTARRAY
 					return d;
 				}
 				/* Far enough past the tolerance that the spheroid calculation won't change things */
-				else if ( d < tolerance * 0.95 )
+				else if ( d <= tolerance * 0.95 )
 				{
 					return d;
 				}
@@ -1930,7 +1934,7 @@ static double ptarray_distance_spheroid(const POINTARRAY *pa1, const POINTARRAY
 				{
 					d = spheroid_distance(&g1, &nearest2, s);
 					/* Yes, closer than tolerance, return! */
-					if ( d < tolerance )
+					if ( d <= tolerance )
 						return d;
 				}
 			}
@@ -1991,7 +1995,7 @@ static double ptarray_distance_spheroid(const POINTARRAY *pa1, const POINTARRAY
 				nearest1 = g1;
 				nearest2 = g2;
 			}
-			if ( d < tolerance )
+			if ( d <= tolerance )
 			{
 				if ( use_sphere )
 				{
@@ -2000,7 +2004,7 @@ static double ptarray_distance_spheroid(const POINTARRAY *pa1, const POINTARRAY
 				else
 				{
 					d = spheroid_distance(&nearest1, &nearest2, s);
-					if ( d < tolerance )
+					if ( d <= tolerance )
 						return d;
 				}
 			}
@@ -2282,7 +2286,7 @@ double lwgeom_distance_spheroid(const LWGEOM *lwgeom1, const LWGEOM *lwgeom2, co
 			double ring_distance = ptarray_distance_spheroid(lwpoly->rings[i], lwpt->point, spheroid, tolerance, check_intersection);
 			if ( ring_distance < distance )
 				distance = ring_distance;
-			if ( distance < tolerance )
+			if ( distance <= tolerance )
 				return distance;
 		}
 		return distance;
@@ -2325,7 +2329,7 @@ double lwgeom_distance_spheroid(const LWGEOM *lwgeom1, const LWGEOM *lwgeom2, co
 			LWDEBUGF(4, "ring[%d] ring_distance = %.8g", i, ring_distance);
 			if ( ring_distance < distance )
 				distance = ring_distance;
-			if ( distance < tolerance )
+			if ( distance <= tolerance )
 				return distance;
 		}
 		LWDEBUGF(4, "all rings checked, returning distance = %.8g", distance);
@@ -2365,7 +2369,7 @@ double lwgeom_distance_spheroid(const LWGEOM *lwgeom1, const LWGEOM *lwgeom2, co
 					check_intersection);
 				if (ring_distance < distance)
 					distance = ring_distance;
-				if (distance < tolerance) return distance;
+				if (distance <= tolerance) return distance;
 			}
 		}
 		return distance;
@@ -2384,7 +2388,7 @@ double lwgeom_distance_spheroid(const LWGEOM *lwgeom1, const LWGEOM *lwgeom2, co
 			    col->geoms[i], lwgeom2, spheroid, tolerance);
 			if ( geom_distance < distance )
 				distance = geom_distance;
-			if ( distance < tolerance )
+			if ( distance <= tolerance )
 				return distance;
 		}
 		return distance;
@@ -2402,7 +2406,7 @@ double lwgeom_distance_spheroid(const LWGEOM *lwgeom1, const LWGEOM *lwgeom2, co
 			double geom_distance = lwgeom_distance_spheroid(lwgeom1, col->geoms[i], spheroid, tolerance);
 			if ( geom_distance < distance )
 				distance = geom_distance;
-			if ( distance < tolerance )
+			if ( distance <= tolerance )
 				return distance;
 		}
 		return distance;
@@ -3351,22 +3355,22 @@ ptarray_nudge_geodetic(POINTARRAY *pa)
 	for(i = 0; i < pa->npoints; i++ )
 	{
 		getPoint4d_p(pa, i, &p);
-		if ( p.x < -180.0 && (-180.0 - p.x < tolerance) )
+		if ( p.x < -180.0 && (-180.0 - p.x <= tolerance) )
 		{
 			p.x = -180.0;
 			altered = LW_TRUE;
 		}
-		if ( p.x > 180.0 && (p.x - 180.0 < tolerance) )
+		if ( p.x > 180.0 && (p.x - 180.0 <= tolerance) )
 		{
 			p.x = 180.0;
 			altered = LW_TRUE;
 		}
-		if ( p.y < -90.0 && (-90.0 - p.y < tolerance) )
+		if ( p.y < -90.0 && (-90.0 - p.y <= tolerance) )
 		{
 			p.y = -90.0;
 			altered = LW_TRUE;
 		}
-		if ( p.y > 90.0 && (p.y - 90.0 < tolerance) )
+		if ( p.y > 90.0 && (p.y - 90.0 <= tolerance) )
 		{
 			p.y = 90.0;
 			altered = LW_TRUE;
