@@ -42,6 +42,7 @@ static uint8_t lwgeom_twkb_type(const LWGEOM *geom)
 		case LINETYPE:
 			twkb_type = WKB_LINESTRING_TYPE;
 			break;
+		case TRIANGLETYPE:
 		case POLYGONTYPE:
 			twkb_type = WKB_POLYGON_TYPE;
 			break;
@@ -54,12 +55,12 @@ static uint8_t lwgeom_twkb_type(const LWGEOM *geom)
 		case MULTIPOLYGONTYPE:
 			twkb_type = WKB_MULTIPOLYGON_TYPE;
 			break;
+		case TINTYPE:
 		case COLLECTIONTYPE:
 			twkb_type = WKB_GEOMETRYCOLLECTION_TYPE;
 			break;
 		default:
-			lwerror("Unsupported geometry type: %s [%d]",
-				lwtype_name(geom->type), geom->type);
+			lwerror("%s: Unsupported geometry type: %s", __func__, lwtype_name(geom->type));
 	}
 	return twkb_type;
 }
@@ -174,7 +175,7 @@ static int ptarray_to_twkb_buf(const POINTARRAY *pa, TWKB_GLOBALS *globals, TWKB
 		/* Skipping the first point is not allowed */
 		/* If the sum(abs()) of all the deltas was zero, */
 		/* then this was a duplicate point, so we can ignore it */
-		if ( i > 0 && diff == 0 && max_points_left > minpoints )
+		if ( i > 0 && diff == 0 &&  max_points_left > minpoints )
 		{
 			max_points_left--;
 			continue;
@@ -254,6 +255,17 @@ static int lwline_to_twkb_buf(const LWLINE *line, TWKB_GLOBALS *globals, TWKB_ST
 	return 0;
 }
 
+static int
+lwtriangle_to_twkb_buf(const LWTRIANGLE *tri, TWKB_GLOBALS *globals, TWKB_STATE *ts)
+{
+	LWDEBUGF(2, "Entered %s", __func__);
+	bytebuffer_append_uvarint(ts->geom_buf, (uint64_t)1);
+
+	/* Set the coordinates (do write npoints) */
+	ptarray_to_twkb_buf(tri->points, globals, ts, 1, 2);
+	return 0;
+}
+
 /******************************************************************
 * POLYGONS
 *******************************************************************/
@@ -379,6 +391,11 @@ static int lwgeom_to_twkb_buf(const LWGEOM *geom, TWKB_GLOBALS *globals, TWKB_ST
 			LWDEBUGF(4,"Type found is Linestring, %d", geom->type);
 			return lwline_to_twkb_buf((LWLINE*) geom, globals, ts);
 		}
+		case TRIANGLETYPE:
+		{
+			LWDEBUGF(4, "Type found is Triangle, %d", geom->type);
+			return lwtriangle_to_twkb_buf((LWTRIANGLE *)geom, globals, ts);
+		}
 		/* Polygon has 'nrings' and 'rings' elements */
 		case POLYGONTYPE:
 		{
@@ -395,13 +412,14 @@ static int lwgeom_to_twkb_buf(const LWGEOM *geom, TWKB_GLOBALS *globals, TWKB_ST
 			return lwmulti_to_twkb_buf((LWCOLLECTION*)geom, globals, ts);
 		}
 		case COLLECTIONTYPE:
+		case TINTYPE:
 		{
 			LWDEBUGF(4,"Type found is collection, %d", geom->type);
 			return lwcollection_to_twkb_buf((LWCOLLECTION*) geom, globals, ts);
 		}
 		/* Unknown type! */
 		default:
-			lwerror("Unsupported geometry type: %s [%d]", lwtype_name((geom)->type), (geom)->type);
+			lwerror("%s: Unsupported geometry type: %s", __func__, lwtype_name(geom->type));
 	}
 
 	return 0;
@@ -567,10 +585,13 @@ static int lwgeom_write_to_buffer(const LWGEOM *geom, TWKB_GLOBALS *globals, TWK
 * Convert LWGEOM to a char* in TWKB format. Caller is responsible for freeing
 * the returned array.
 */
-uint8_t*
-lwgeom_to_twkb_with_idlist(const LWGEOM *geom, int64_t *idlist, uint8_t variant,
-               int8_t precision_xy, int8_t precision_z, int8_t precision_m,
-               size_t *twkb_size)
+lwvarlena_t *
+lwgeom_to_twkb_with_idlist(const LWGEOM *geom,
+			   int64_t *idlist,
+			   uint8_t variant,
+			   int8_t precision_xy,
+			   int8_t precision_z,
+			   int8_t precision_m)
 {
 	LWDEBUGF(2, "Entered %s", __func__);
 	LWDEBUGF(2, "variant value %x", variant);
@@ -579,8 +600,6 @@ lwgeom_to_twkb_with_idlist(const LWGEOM *geom, int64_t *idlist, uint8_t variant,
 	TWKB_STATE ts;
 	bytebuffer_t geom_bytebuffer;
 
-	uint8_t *twkb;
-
 	memset(&ts, 0, sizeof(TWKB_STATE));
 	memset(&tg, 0, sizeof(TWKB_GLOBALS));
 
@@ -608,18 +627,15 @@ lwgeom_to_twkb_with_idlist(const LWGEOM *geom, int64_t *idlist, uint8_t variant,
 	bytebuffer_init_with_size(ts.geom_buf, 512);
 	lwgeom_write_to_buffer(geom, &tg, &ts);
 
-	twkb = bytebuffer_get_buffer_copy(ts.geom_buf, twkb_size);
+	lwvarlena_t *v = bytebuffer_get_buffer_varlena(ts.geom_buf);
 	bytebuffer_destroy_buffer(ts.geom_buf);
-	return twkb;
+	return v;
 }
 
-
-uint8_t*
-lwgeom_to_twkb(const LWGEOM *geom, uint8_t variant,
-               int8_t precision_xy, int8_t precision_z, int8_t precision_m,
-               size_t *twkb_size)
+lwvarlena_t *
+lwgeom_to_twkb(const LWGEOM *geom, uint8_t variant, int8_t precision_xy, int8_t precision_z, int8_t precision_m)
 {
-	return lwgeom_to_twkb_with_idlist(geom, NULL, variant, precision_xy, precision_z, precision_m, twkb_size);
+	return lwgeom_to_twkb_with_idlist(geom, NULL, variant, precision_xy, precision_z, precision_m);
 }
 
 
