@@ -105,9 +105,9 @@ Datum ST_Equals(PG_FUNCTION_ARGS);
 Datum ST_BuildArea(PG_FUNCTION_ARGS);
 Datum ST_DelaunayTriangles(PG_FUNCTION_ARGS);
 Datum ST_MaximumInscribedCircle(PG_FUNCTION_ARGS);
-
+Datum ST_ConcaveHull(PG_FUNCTION_ARGS);
+Datum ST_SimplifyPolygonHull(PG_FUNCTION_ARGS);
 Datum pgis_union_geometry_array(PG_FUNCTION_ARGS);
-Datum pgis_geometry_union_finalfn(PG_FUNCTION_ARGS);
 
 /*
 ** Prototypes end
@@ -635,88 +635,6 @@ Datum pgis_union_geometry_array(PG_FUNCTION_ARGS)
 }
 
 
-PG_FUNCTION_INFO_V1(pgis_geometry_union_finalfn);
-Datum pgis_geometry_union_finalfn(PG_FUNCTION_ARGS)
-{
-	CollectionBuildState *state;
-	ListCell *l;
-	LWGEOM **geoms;
-	GSERIALIZED *gser_out;
-	size_t ngeoms = 0;
-	int empty_type = 0;
-	bool first = true;
-	int32_t srid = SRID_UNKNOWN;
-	int has_z = LW_FALSE;
-
-	if (PG_ARGISNULL(0))
-		PG_RETURN_NULL(); /* returns null iff no input values */
-
-	state = (CollectionBuildState *)PG_GETARG_POINTER(0);
-	geoms = palloc(list_length(state->geoms) * sizeof(LWGEOM*));
-
-	/* Read contents of list into an array of only non-null values */
-	foreach (l, state->geoms)
-	{
-		LWGEOM *geom = (LWGEOM*)(lfirst(l));
-		if (geom)
-		{
-			if (!lwgeom_is_empty(geom))
-			{
-				geoms[ngeoms++] = geom;
-				if (first)
-				{
-					srid = lwgeom_get_srid(geom);
-					has_z = lwgeom_has_z(geom);
-					first = false;
-				}
-			}
-			else
-			{
-				int type = lwgeom_get_type(geom);
-				empty_type = type > empty_type ? type : empty_type;
-				srid = (srid != SRID_UNKNOWN ? srid : lwgeom_get_srid(geom));
-			}
-		}
-	}
-
-	/*
-	** Take our array of LWGEOM* and turn it into a GEOS collection,
-	** then pass that into cascaded union.
-	*/
-	if (ngeoms > 0)
-	{
-		LWCOLLECTION* col = lwcollection_construct(COLLECTIONTYPE, srid, NULL, ngeoms, geoms);
-		LWGEOM *out = lwgeom_unaryunion_prec(lwcollection_as_lwgeom(col), state->gridSize);
-		if ( ! out )
-		{
-			lwcollection_free(col);
-		}
-		gser_out = geometry_serialize(out);
-	}
-	/* No real geometries in our array, any empties? */
-	else
-	{
-		/* If it was only empties, we'll return the largest type number */
-		if (empty_type > 0)
-			PG_RETURN_POINTER(
-			    geometry_serialize(lwgeom_construct_empty(empty_type, srid, has_z, 0)));
-
-		/* Nothing but NULL, returns NULL */
-		else
-			PG_RETURN_NULL();
-	}
-
-	if (!gser_out)
-	{
-		/* Union returned a NULL geometry */
-		PG_RETURN_NULL();
-	}
-
-	PG_RETURN_POINTER(gser_out);
-}
-
-
-
 /**
  * @example ST_UnaryUnion {@link #geomunion} SELECT ST_UnaryUnion(
  *      'POLYGON((0 0, 10 0, 0 10, 10 10, 0 0))'
@@ -889,6 +807,63 @@ Datum convexhull(PG_FUNCTION_ARGS)
 	PG_RETURN_POINTER(result);
 }
 
+
+PG_FUNCTION_INFO_V1(ST_ConcaveHull);
+Datum ST_ConcaveHull(PG_FUNCTION_ARGS)
+{
+#if POSTGIS_GEOS_VERSION < 31100
+
+	lwpgerror("The GEOS version this PostGIS binary "
+				"was compiled against (%d) doesn't support "
+				"'GEOSConcaveHull' function (3.11.0+ required)",
+				POSTGIS_GEOS_VERSION);
+	PG_RETURN_NULL();
+
+#else /* POSTGIS_GEOS_VERSION >= 31100 */
+	GSERIALIZED* geom = PG_GETARG_GSERIALIZED_P(0);
+	double ratio = PG_GETARG_FLOAT8(1);
+	bool allow_holes = PG_GETARG_BOOL(2);
+
+	LWGEOM* lwgeom = lwgeom_from_gserialized(geom);
+	LWGEOM* lwresult = lwgeom_concavehull(lwgeom, ratio, allow_holes);
+	GSERIALIZED* result = geometry_serialize(lwresult);
+
+	lwgeom_free(lwgeom);
+	lwgeom_free(lwresult);
+	PG_FREE_IF_COPY(geom, 0);
+	PG_RETURN_POINTER(result);
+#endif
+}
+
+
+PG_FUNCTION_INFO_V1(ST_SimplifyPolygonHull);
+Datum ST_SimplifyPolygonHull(PG_FUNCTION_ARGS)
+{
+#if POSTGIS_GEOS_VERSION < 31100
+
+	lwpgerror("The GEOS version this PostGIS binary "
+				"was compiled against (%d) doesn't support "
+				"'ST_SimplifyPolygonHull' function (3.11.0+ required)",
+				POSTGIS_GEOS_VERSION);
+	PG_RETURN_NULL();
+
+#else /* POSTGIS_GEOS_VERSION >= 31100 */
+	GSERIALIZED* geom = PG_GETARG_GSERIALIZED_P(0);
+	double vertex_fraction = PG_GETARG_FLOAT8(1);
+	uint32_t is_outer = PG_GETARG_BOOL(2);
+
+	LWGEOM* lwgeom = lwgeom_from_gserialized(geom);
+	LWGEOM* lwresult = lwgeom_simplify_polygonal(lwgeom, vertex_fraction, is_outer);
+	GSERIALIZED* result = geometry_serialize(lwresult);
+
+	lwgeom_free(lwgeom);
+	lwgeom_free(lwresult);
+	PG_FREE_IF_COPY(geom, 0);
+	PG_RETURN_POINTER(result);
+#endif
+}
+
+
 PG_FUNCTION_INFO_V1(topologypreservesimplify);
 Datum topologypreservesimplify(PG_FUNCTION_ARGS)
 {
@@ -3086,15 +3061,18 @@ PG_FUNCTION_INFO_V1(linemerge);
 Datum linemerge(PG_FUNCTION_ARGS)
 {
 	GSERIALIZED *geom1;
+	bool directed = false;
 	GSERIALIZED *result;
 	LWGEOM *lwgeom1, *lwresult ;
 
 	geom1 = PG_GETARG_GSERIALIZED_P(0);
 
+	if ( PG_NARGS() > 1 )
+		directed = PG_GETARG_BOOL(1);
 
 	lwgeom1 = lwgeom_from_gserialized(geom1) ;
 
-	lwresult = lwgeom_linemerge(lwgeom1);
+	lwresult = lwgeom_linemerge_directed(lwgeom1, directed ? LW_TRUE : LW_FALSE);
 	result = geometry_serialize(lwresult) ;
 
 	lwgeom_free(lwgeom1) ;
@@ -3172,6 +3150,43 @@ Datum ST_DelaunayTriangles(PG_FUNCTION_ARGS)
 	PG_RETURN_POINTER(result);
 }
 
+/*
+ * Take a polygon and build a constrained
+ * triangulation that respect the edges of the
+ * polygon.
+ */
+PG_FUNCTION_INFO_V1(ST_TriangulatePolygon);
+Datum ST_TriangulatePolygon(PG_FUNCTION_ARGS)
+{
+#if POSTGIS_GEOS_VERSION < 31100
+
+	lwpgerror("The GEOS version this PostGIS binary "
+	          "was compiled against (%d) doesn't support "
+	          "'GEOSConstrainedDelaunayTriangulation' function (3.11.0+ required)",
+	          POSTGIS_GEOS_VERSION);
+	PG_RETURN_NULL();
+
+#else /* POSTGIS_GEOS_VERSION >= 31100 */
+	GSERIALIZED *result;
+	GSERIALIZED *geom = PG_GETARG_GSERIALIZED_P(0);
+	LWGEOM *lwgeom_in = lwgeom_from_gserialized(geom);
+	LWGEOM *lwgeom_out = lwgeom_triangulate_polygon(lwgeom_in);
+	lwgeom_free(lwgeom_in);
+
+	if (!lwgeom_out)
+	{
+		PG_FREE_IF_COPY(geom, 0);
+		PG_RETURN_NULL();
+	}
+
+	result = geometry_serialize(lwgeom_out);
+	lwgeom_free(lwgeom_out);
+
+	PG_FREE_IF_COPY(geom, 0);
+	PG_RETURN_POINTER(result);
+#endif
+}
+
 /*
  * ST_Snap
  *
