@@ -339,6 +339,26 @@ regexp_replace(probin, '(rt)?postgis(_[^-]*)?(-[0-9.]*)$', '\3')
 )
 ORDER BY 2;
 
+-- Make sure all postgis functions are owned by the
+-- same role as postgis_lib_version
+SELECT DISTINCT 'unexpected ownership', proname || ':' || proowner::regrole
+FROM pg_proc
+WHERE (
+	probin like '%postgis%'
+  OR (
+		probin is null and
+		oid::regprocedure::text like 'st\_%' or
+		oid::regprocedure::text like 'postgis_%'
+	)
+)
+AND proowner !=
+(
+	SELECT
+	proowner
+	FROM pg_proc WHERE proname = 'postgis_lib_version'
+)
+ORDER BY 2;
+
 
 SELECT 'UNEXPECTED', postgis_full_version()
 	WHERE postgis_full_version() LIKE '%UNPACKAGED%'
