@@ -86,3 +86,12 @@ SELECT ST_AsEWKT(ST_LineToCurve('LINESTRING(
 		-13151496.921063 3913666.61175287,
 		-13151521.3839744 3913666.61175287,
 		-13151591.4368571 3913665.36595828)'));
+
+SELECT 'pt1', ST_AsEWKT(ST_Point(1.0, 2.0));
+SELECT 'pt2', ST_AsEWKT(ST_Point(1.0, 2.0, 3));
+SELECT 'pt3', ST_AsEWKT(ST_PointZ(1.0, 2.0, 3.0));
+SELECT 'pt4', ST_AsEWKT(ST_PointZ(1.0, 2.0, 3.0, 4));
+SELECT 'pt5', ST_AsEWKT(ST_PointM(1.0, 2.0, 3.0));
+SELECT 'pt6', ST_AsEWKT(ST_PointM(1.0, 2.0, 3.0, 4));
+SELECT 'pt7', ST_AsEWKT(ST_PointZM(1.0, 2.0, 3.0, 4.0));
+SELECT 'pt8', ST_AsEWKT(ST_PointZM(1.0, 2.0, 3.0, 4.0, 5));
