@@ -5,6 +5,7 @@ DROP VIEW IF EXISTS upgrade_view_test_union;
 DROP VIEW IF EXISTS upgrade_view_test_force_dims;
 DROP VIEW IF EXISTS upgrade_view_test_askml;
 DROP VIEW IF EXISTS upgrade_view_test_dwithin;
+DROP VIEW IF EXISTS upgrade_view_test_clusterkmeans;
 DROP TABLE upgrade_test;
 
 -- Drop functions deprecated on upgrade
@@ -21,3 +22,4 @@ DROP FUNCTION IF EXISTS st_askml_deprecated_by_postgis_200(geometry,integer);
 DROP FUNCTION IF EXISTS st_askml_deprecated_by_postgis_200(geography,integer);
 DROP FUNCTION IF EXISTS st_dwithin_deprecated_by_postgis_300(geography,geography,float8);
 DROP FUNCTION IF EXISTS st_dwithin_deprecated_by_postgis_300(text,text,float8);
+DROP FUNCTION IF EXISTS st_clusterkmeans_deprecated_by_postgis_302(geometry,integer);
